@@ -1,5 +1,5 @@
 """Notebook stream results."""
-from __future__ import annotations
+
 
 import dataclasses
 from typing import ClassVar, Iterator, Union
@@ -10,6 +10,25 @@ from rich.console import ConsoleRenderable
 from rich.padding import Padding
 
 
+@dataclasses.dataclass
+class Stream:
+    """A stream output."""
+
+    content: str
+    name: ClassVar[str]
+
+    def __rich__(self) -> Union[ConsoleRenderable, str]:
+        """Render the stream."""
+        return self.content
+
+    @classmethod
+    def from_output(cls, output: NotebookNode) -> "Stream":
+        """Create stream from notebook output."""
+        stream_text = output.get("text", "")
+        text = stream_text[:-1] if stream_text.endswith("\n") else stream_text
+        return cls(text)
+
+
 def render_stream(output: NotebookNode) -> Iterator[Stream]:
     """Render a stream type output.
 
@@ -28,25 +47,6 @@ def render_stream(output: NotebookNode) -> Iterator[Stream]:
     yield stream
 
 
-@dataclasses.dataclass
-class Stream:
-    """A stream output."""
-
-    content: str
-    name: ClassVar[str]
-
-    def __rich__(self) -> Union[ConsoleRenderable, str]:
-        """Render the stream."""
-        return self.content
-
-    @classmethod
-    def from_output(cls, output: NotebookNode) -> Stream:
-        """Create stream from notebook output."""
-        stream_text = output.get("text", "")
-        text = stream_text[:-1] if stream_text.endswith("\n") else stream_text
-        return cls(text)
-
-
 @dataclasses.dataclass
 class StdErr(Stream):
     """A stderr stream output."""
@@ -54,7 +54,7 @@ class StdErr(Stream):
     name: ClassVar[str] = "stderr"
 
     @classmethod
-    def from_output(cls, output: NotebookNode) -> StdErr:
+    def from_output(cls, output: NotebookNode) -> "StdErr":
         """Create stderr from notebook output."""
         if output["name"] != cls.name:
             raise ValueError(f"Output does not contain a {cls.name} stream")
